@@ -21,7 +21,7 @@ namespace Parsers
 }
 
 class AptProtocol : public TQObject, public TDEIO::SlaveBase {
-  Q_OBJECT
+  TQ_OBJECT
   
 
   friend class AptCache;
@@ -85,7 +85,7 @@ private slots:
   void token_dispatch(const TQString& tag, const TQString& value);
 
 private:
-  std::auto_ptr<Parsers::Parser> m_parser;
+  std::unique_ptr<Parsers::Parser> m_parser;
 
   /** apt-cache search
    * Performs apt-cache search, with the query encoded in url.query()
