@@ -20,7 +20,7 @@
 */
 class Dpkg : public PackageManager
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
   typedef void (Dpkg::*ReceiveMethod) (const TQStringList& lines);
